@@ -1,4 +1,11 @@
-from peewee import *
+from peewee import (
+    AutoField,
+    CharField,
+    DatabaseProxy,
+    ForeignKeyField,
+    Model,
+    MySQLDatabase,
+)
 
 from piicatcher.catalog import Store
 from piicatcher.catalog.pii_type_field import PiiTypeField
@@ -19,14 +26,14 @@ class DbSchemas(BaseModel):
 class DbTables(BaseModel):
     id = AutoField()
     name = CharField()
-    schema_id = ForeignKeyField(DbSchemas, 'id')
+    schema_id = ForeignKeyField(DbSchemas, "id")
 
 
 class DbColumns(BaseModel):
     id = AutoField()
     name = CharField()
     pii_type = PiiTypeField()
-    table_id = ForeignKeyField(DbTables, 'id')
+    table_id = ForeignKeyField(DbTables, "id")
 
 
 class DbFile(BaseModel):
@@ -44,11 +51,13 @@ class DbStore(Store):
     @classmethod
     def setup_database(cls, catalog):
         if catalog is not None:
-            database = MySQLDatabase('tokern',
-                                     host=catalog['host'],
-                                     port=int(catalog['port']),
-                                     user=catalog['user'],
-                                     password=catalog['password'])
+            database = MySQLDatabase(
+                "tokern",
+                host=catalog["host"],
+                port=int(catalog["port"]),
+                user=catalog["user"],
+                password=catalog["password"],
+            )
             database_proxy.initialize(database)
             database_proxy.connect()
             database_proxy.create_tables([DbSchemas, DbTables, DbColumns, DbFile])
@@ -59,15 +68,19 @@ class DbStore(Store):
         with database_proxy.atomic():
             schemas = explorer.get_schemas()
             for s in schemas:
-                schema_model, schema_created = DbSchemas.get_or_create(name=s.get_name())
+                schema_model, schema_created = DbSchemas.get_or_create(
+                    name=s.get_name()
+                )
                 print(schema_model)
                 for t in s.get_children():
-                    tbl_model, tbl_created = DbTables.get_or_create(schema_id=schema_model.id,
-                                                                    name=t.get_name())
+                    tbl_model, tbl_created = DbTables.get_or_create(
+                        schema_id=schema_model.id, name=t.get_name()
+                    )
 
                     for c in t.get_children():
-                        col_model, col_created = DbColumns.get_or_create(table_id=tbl_model.id,
-                                                                         name=c.get_name())
+                        col_model, col_created = DbColumns.get_or_create(
+                            table_id=tbl_model.id, name=c.get_name()
+                        )
                         if col_created:
                             col_model.pii_type = c.get_pii_types()
                             col_model.save()
